#ifndef APPPARAMETERS_H
#define APPPARAMETERS_H

#include "mbed.h"
#include "settings.h"

typedef struct {
    unsigned int estadoRele;
    unsigned int RELIGAR_LARGURA_PULSO_MS;    // Largura do pulso enviado ao rele em milissegundos para religar
    unsigned int CORTAR_LARGURA_PULSO_MS;     // Largura do pulso enviado ao rele em milissegundos para cortar
    unsigned int DELAY_SENSOR_MS;             // Tempo esperado apos enviar um pulso para o rele e antes de verificar o estado do sensor de fornecimento (em milissegundos)
    unsigned int INTERVALO_SILENCIO_S;        // intervalo sem receber bytes na rede para considerar que a linha esta livre pra envio do anuncio
    unsigned int INTERVALO_WD_NETWORK_S;      // intervalo de watchdog da comunicacao de rede, em segundos. Se nao receber comandos apos este periodo vai resetar
    unsigned int LIMITE_TENSAO_SENSOR_V;      // Limite de tensao em volts RMS no conversor A/D para considerar que a linha esta energizada
    unsigned int SAMPLES;                     // Numero de amostras para calculo da tensao RMS nos sensores de carga e linha
    unsigned int SAMPLES_DELAY_US;            // Intervalo entre amostras para calculo da tensao RMS (em microssegundos)
    union{
        float floatValue;                     // Coeficiente angular das amostras de tensao do A/D
        char bytes[4];
    } SAMPLES_ANG_COEF;
    union{
        float floatValue;                     // Coeficiente linear das amostras de tensao do A/D
        char bytes[4];
    } SAMPLES_LIN_COEF;
    unsigned char LOAD_CHANNEL;               // Indica o canal (0 ou 1) onde esta ligada a carga, para que as rotinas de corte e religa verifiquem a alimentacao corretamente
    unsigned int INTERVALO_MM_S;              // Intervalo de leitura de Memoria de Massa em segundos
    unsigned int MM_SIZE;                     // Numero maximo de registros da memoria de massa
    char reserved[3];                         // Apenas para completar numero de bytes para ficar multiplo de 8
} ParametersBlock;

void validateAppParameters();

extern ParametersBlock APP_PARAMETERS;


#endif
