#include "main.h"

static Watchdog wd;
static Ticker tickerWd;
SerialNumber sn;
Parameters param ((char *)&APP_PARAMETERS, sizeof(APP_PARAMETERS));
CommandExecutor exec;
MemoriaMassa mm;

int main()
{
    iniciaWd();
    
    printf("##### %s #####\r\n", version);
    printSerialNumber();

    param.loadParameters();
    printParameters();
    
    mm.iniciaLeituras(APP_PARAMETERS.INTERVALO_MM_S, APP_PARAMETERS.MM_SIZE);
    
    ggsStream.baud(19200);
    exec.carregaEndereco(sn.get());
    exec.iniciaExecutorComandos(APP_PARAMETERS.INTERVALO_WD_NETWORK_S, APP_PARAMETERS.INTERVALO_SILENCIO_S);
    detectaCargaSemCorte();
    
    while(1){
        exec.trataPacoteGGS();
        mm.executaLeitura();
    }
    
}

void iniciaWd(){
    wd.Configure();
    tickerWd.attach(&feedWd, WATCHDOG_INTERVAL);
}

void feedWd(){
    wd.Service();
}

void softReset(){
    printf("SoftReset\r\n");
    tickerWd.detach();
}

void printSerialNumber(){
    printf("SN: ");
    for(int i=0; i < SERIAL_LENGTH; i++){
        printf("%c", sn.get()[i]);
    }
    printf("\r\n");
}

void printParameters(){
    printf("Parameters:");
    for(int i=0; i < sizeof(APP_PARAMETERS); i++){
        printf(" %02x", ((char *)&APP_PARAMETERS)[i]);
    }
    printf("\r\n");
}

void detectaCargaSemCorte(){
    bool ch0Status = getEstadoSensor(0);
    bool ch1Status = getEstadoSensor(1);
    
    if(!ch0Status && ch1Status){    // Canal 0 nao esta alimentado e Canal 1 esta: entao a carga certamente e o canal 0
        if(APP_PARAMETERS.LOAD_CHANNEL != 0){
            APP_PARAMETERS.LOAD_CHANNEL = 0;
            param.saveParameters();
        }
    } else if(ch0Status && !ch1Status){    // Canal 1 nao esta alimentado e Canal 0 esta: entao a carga certamente e o canal 1
        if(APP_PARAMETERS.LOAD_CHANNEL != 1){
            APP_PARAMETERS.LOAD_CHANNEL = 1;
            param.saveParameters();
        }
    }
}
